@@ -12,8 +12,7 @@ from typing import Dict, Any, Optional, List
 
 # Import from modularized components
 from .config import (
-    get_analysis_config, LLM_PROVIDER, LLM_MODELS, 
-    LLM_TEMPERATURE, LLM_TOP_P
+    get_analysis_config, LLM_PROVIDER, LLM_MODELS
 )
 from .llm import initialize_llm_model, generate_with_model, wait_on_failure
 from .elasticsearch import send_to_elasticsearch_raw
@@ -409,6 +408,9 @@ def run_generic_realtime_analysis(log_type: str, analysis_schema_class, prompt_t
                 if success:
                     print("✅ Real-time analysis completed successfully")
                     
+                    # Mark chunk as processed (this updates the position)
+                    monitor.mark_chunk_processed(chunk_lines)
+                    
                     # Show high severity events summary
                     if parsed_data and 'events' in parsed_data:
                         event_count = len(parsed_data['events'])
@@ -435,6 +437,9 @@ def run_generic_realtime_analysis(log_type: str, analysis_schema_class, prompt_t
             
     except KeyboardInterrupt:
         print("\n\n🛑 Real-time monitoring stopped by user")
+        # Save current position (pending lines will be reprocessed on restart)
+        if 'monitor' in locals():
+            monitor.save_state_on_exit()
         print("Position saved. You can resume monitoring from where you left off.")
     except FileNotFoundError:
         print(f"ERROR: Log file not found: {config['log_path']}")
